@@ -7,6 +7,8 @@ tokenizer_regexes = [
     ('"([^"]*)"', r" `` \1 '' "),
     (r'([.,:;?!%]+) ', r" \1 "),
     (r'([.,:;?!%]+)$', r" \1"),
+    (r'(\.\.+)(\w)', r" \1 \2"),
+    (r'(--+)(\w)', r" \1 \2"),
     (r'([()])', r" \1 "),
     (r'  +', ' ')]
 
